// Copyright (C) 2022 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'dart:async';

import 'package:wyatt_architecture/wyatt_architecture.dart';
import 'package:wyatt_crud_bloc/src/core/enums/operation_type.dart';

export 'create.dart';
export 'delete.dart';
export 'delete_all.dart';
export 'get.dart';
export 'get_all.dart';
export 'params/params.dart';
export 'search.dart';
export 'update.dart';
export 'update_all.dart';

abstract class Usecase<In, Out> extends AsyncUseCase<In, Out> {
  const Usecase();

  @override
  FutureOr<void> onStart(In? params) {
    if (params == null) {
      throw ClientException('$In cannot be null.');
    }
  }

  OperationType get operationType;
}

abstract class NoParamUsecase<Out> extends AsyncUseCase<void, Out> {
  const NoParamUsecase();

  OperationType get operationType;
}
