// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/components/gradients/gradient_text_style.dart';
import 'package:wyatt_ui_kit/src/core/design_system/colors.dart';

class RichTextBuilderThemeExtensionImpl extends RichTextBuilderThemeExtension {
  const RichTextBuilderThemeExtensionImpl({
    super.defaultStyle,
    super.styles,
  });

  factory RichTextBuilderThemeExtensionImpl.dark({ThemeData? theme}) {
    theme ??= ThemeData.dark();

    return RichTextBuilderThemeExtensionImpl(
      defaultStyle: theme.textTheme.bodyMedium?.copyWith(
        height: 1.8,
      ),
      styles: stylesFor(theme),
    );
  }

  factory RichTextBuilderThemeExtensionImpl.light({ThemeData? theme}) {
    theme ??= ThemeData.light();

    return RichTextBuilderThemeExtensionImpl(
      defaultStyle: theme.textTheme.bodyMedium?.copyWith(
        height: 1.8,
      ),
      styles: stylesFor(theme),
    );
  }

  static Map<String, TextStyle> stylesFor(ThemeData theme) => {
        'gradient-blue': GradientTextStyle.from(
          theme.textTheme.bodyMedium?.copyWith(
            fontWeight: FontWeight.w600,
            height: 1.8,
          ),
          WyattColors.blueGradient,
        ),
        'gradient-dark-blue': GradientTextStyle.from(
          theme.textTheme.bodyMedium?.copyWith(
            fontWeight: FontWeight.w600,
            height: 1.8,
          ),
          WyattColors.darkBlueGradient,
        ),
        'gradient-gray': GradientTextStyle.from(
          theme.textTheme.bodyMedium?.copyWith(
            fontWeight: FontWeight.w600,
            height: 1.8,
          ),
          WyattColors.grayGradient,
        ),
        'gradient-light-gray': GradientTextStyle.from(
          theme.textTheme.bodyMedium?.copyWith(
            fontWeight: FontWeight.w600,
            height: 1.8,
          ),
          WyattColors.lightGrayGradient,
        ),
        'gradient-light': GradientTextStyle.from(
          theme.textTheme.bodyMedium?.copyWith(
            fontWeight: FontWeight.w600,
            height: 1.8,
          ),
          WyattColors.lightGradient,
        ),
        'gradient-purple': GradientTextStyle.from(
          theme.textTheme.bodyMedium?.copyWith(
            fontWeight: FontWeight.w600,
            height: 1.8,
          ),
          WyattColors.purpleGradient,
        ),
        'gradient-red': GradientTextStyle.from(
          theme.textTheme.bodyMedium?.copyWith(
            fontWeight: FontWeight.w600,
            height: 1.8,
          ),
          WyattColors.redGradient,
        ),
        'gradient-yellow': GradientTextStyle.from(
          theme.textTheme.bodyMedium?.copyWith(
            fontWeight: FontWeight.w600,
            height: 1.8,
          ),
          WyattColors.yellowGradient,
        ),
        'gradient-green': GradientTextStyle.from(
          theme.textTheme.bodyMedium?.copyWith(
            fontWeight: FontWeight.w600,
            height: 1.8,
          ),
          WyattColors.greenGradient,
        ),
        'blue': theme.textTheme.bodyMedium?.copyWith(
              fontWeight: FontWeight.w600,
              color: WyattColors.blue1,
              height: 1.8,
            ) ??
            const TextStyle(
              color: WyattColors.blue1,
            ),
        'dark-blue': theme.textTheme.bodyMedium?.copyWith(
              fontWeight: FontWeight.w600,
              color: WyattColors.darkBlue1,
              height: 1.8,
            ) ??
            const TextStyle(
              color: WyattColors.darkBlue1,
            ),
        'gray': theme.textTheme.bodyMedium?.copyWith(
              fontWeight: FontWeight.w600,
              color: WyattColors.gray1,
              height: 1.8,
            ) ??
            const TextStyle(
              color: WyattColors.gray1,
            ),
        'green': theme.textTheme.bodyMedium?.copyWith(
              fontWeight: FontWeight.w600,
              color: WyattColors.green1,
              height: 1.8,
            ) ??
            const TextStyle(
              color: WyattColors.green1,
            ),
        'light': theme.textTheme.bodyMedium?.copyWith(
              fontWeight: FontWeight.w600,
              color: WyattColors.light,
              height: 1.8,
            ) ??
            const TextStyle(
              color: WyattColors.light,
            ),
        'light-gray': theme.textTheme.bodyMedium?.copyWith(
              fontWeight: FontWeight.w600,
              color: WyattColors.lightGray1,
              height: 1.8,
            ) ??
            const TextStyle(
              color: WyattColors.lightGray1,
            ),
        'purple': theme.textTheme.bodyMedium?.copyWith(
              fontWeight: FontWeight.w600,
              color: WyattColors.purple1,
              height: 1.8,
            ) ??
            const TextStyle(
              color: WyattColors.purple1,
            ),
        'red': theme.textTheme.bodyMedium?.copyWith(
              fontWeight: FontWeight.w600,
              color: WyattColors.red1,
              height: 1.8,
            ) ??
            const TextStyle(color: WyattColors.red1),
        'yellow': theme.textTheme.bodyMedium?.copyWith(
              fontWeight: FontWeight.w600,
              color: WyattColors.yellow1,
              height: 1.8,
            ) ??
            const TextStyle(color: WyattColors.yellow1),
      };
}
